@@ -1,5 +1,7 @@
 from maisaedu_utilities_prefect.constants.env import LOCAL, DEV, PROD
 
+LOGGER_PREFECT = "prefect"
+
 FULL = "full"
 INCREMENTAL = "incremental"
 
@@ -7,6 +9,8 @@ PREFECT_DMS = "prefect-dms"
 PREFECT = "prefect"
 
 SAVED_S3 = "saved-s3"
+DELETED_S3 = "deleted-s3"
+PRE_DELETED_S3 = "pre-deleted-s3"
 SAVED_REDSHIFT = "saved-redshift"
 
 S3 = "s3"
